@@ -1,4 +1,4 @@
-### Copyright (C) 2002-2005 Stephen Kennedy <stevek@gnome.org>
+### Copyright (C) 2002-2006 Stephen Kennedy <stevek@gnome.org>
 
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the GNU General Public License as published by
@@ -178,6 +178,7 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
         self.find_dialog = None
         self.last_search = None
         self.set_num_panes(num_panes)
+        gtk.idle_add( lambda *args: self.load_font()) # hack around Bug 316730
 
     def _update_regexes(self):
         self.regexes = []
@@ -900,18 +901,22 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
         self.scheduler.add_task( lambda : self._sync_vscroll( self.scrolledwindow[src_pane].get_vadjustment() ) and None )
 
         #
-        # refresh
+        # refresh and reload
         #
-    def refresh(self, junk=None):
+    def on_reload_activate(self, *extra):
         modified = [b.filename for b in self.bufferdata if b.modified]
         if len(modified):
-            message = _("Refreshing will discard changes in:\n%s\n\nYou cannot undo this operation.") % "\n".join(modified)
+            message = _("Reloading will discard changes in:\n%s\n\nYou cannot undo this operation.") % "\n".join(modified)
             response = misc.run_dialog( message, parent=self, messagetype=gtk.MESSAGE_WARNING, buttonstype=gtk.BUTTONS_OK_CANCEL)
             if response != gtk.RESPONSE_OK:
                 return
         files = [b.filename for b in self.bufferdata[:self.num_panes] ]
         self.set_files(files)
 
+    def on_refresh_activate(self, *extra):
+        files = [None for b in self.bufferdata[:self.num_panes] ]
+        self.set_files(files)
+
     def queue_draw(self, junk=None):
         for i in range(self.num_panes-1):
             self.linkmap[i].queue_draw()
