@@ -1,4 +1,4 @@
-### Copyright (C) 2002-2005 Stephen Kennedy <stevek@gnome.org>
+### Copyright (C) 2002-2006 Stephen Kennedy <stevek@gnome.org>
 
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the GNU General Public License as published by
@@ -83,6 +83,10 @@ class MeldDoc(gobject.GObject):
                 self.undosequence_busy = 0
             self.undosequence_busy = 0
 
+    def on_refresh_activate(self, *extra):
+        self.on_reload_activate(self, *extra)
+    def on_reload_activate(self, *extra):
+        pass
     def on_find_activate(self, *extra):
         pass
     def on_find_next_activate(self, *extra):
