@@ -1,4 +1,4 @@
-### Copyright (C) 2002-2005 Stephen Kennedy <stevek@gnome.org>
+### Copyright (C) 2002-2006 Stephen Kennedy <stevek@gnome.org>
 
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the GNU General Public License as published by
@@ -312,6 +312,7 @@ class VcView(melddoc.MeldDoc, gnomeglade.Component):
     def on_button_press_event(self, text, event):
         if event.button==3:
             VcMenu(self, event)
+            return len(self._get_selected_treepaths()) != 1
         return 0
 
     def on_button_flatten_toggled(self, button):
@@ -420,7 +421,6 @@ class VcView(melddoc.MeldDoc, gnomeglade.Component):
         tmpdir = tempfile.mkdtemp("-meld")
         self.tempdirs.append(tmpdir)
 
-        regex = re.compile("^diff(.*$)", re.M)
         regex = re.compile(self.vc.PATCH_INDEX_RE, re.M)
         files = [f.split()[-1] for f in regex.findall(patch)]
         diffs = []
@@ -568,3 +568,5 @@ class VcView(melddoc.MeldDoc, gnomeglade.Component):
                 goto_iter(it)
                 return
 
+    def on_reload_activate(self, *extra):
+        self.on_fileentry_activate(self.fileentry)
